==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/NextMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextMonthExpressionDescription } from "./NextMonthExpressionDescription";
/**
 * @hidden
 */
export let NextMonthExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class NextMonthExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (NextMonthExpressionDescriptionMetadata.a == null) {
                NextMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NextMonthExpressionDescriptionMetadata.c(NextMonthExpressionDescriptionMetadata.a);
            }
            if (a.k(NextMonthExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(NextMonthExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            NextMonthExpressionDescriptionMetadata.b(a);
            a.ad("NextMonthExpression", () => new NextMonthExpressionDescription());
            a.ac("NextMonthExpression", NextMonthExpressionDescriptionMetadata.a);
        }
    }
    NextMonthExpressionDescriptionMetadata.$t = markType(NextMonthExpressionDescriptionMetadata, 'NextMonthExpressionDescriptionMetadata');
    NextMonthExpressionDescriptionMetadata.a = null;
    return NextMonthExpressionDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/NextMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { NextMonthExpressionDescription } from "./NextMonthExpressionDescription";
/**
 * @hidden
 */
export let NextMonthExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class NextMonthExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (NextMonthExpressionDescriptionMetadata.a == null) {
                NextMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NextMonthExpressionDescriptionMetadata.c(NextMonthExpressionDescriptionMetadata.a);
            }
            if (a.k(NextMonthExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(NextMonthExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            NextMonthExpressionDescriptionMetadata.b(a);
            a.ae("NextMonthExpression", () => new NextMonthExpressionDescription());
            a.ad("NextMonthExpression", NextMonthExpressionDescriptionMetadata.a);
        }
    }
    NextMonthExpressionDescriptionMetadata.$t = markType(NextMonthExpressionDescriptionMetadata, 'NextMonthExpressionDescriptionMetadata');
    NextMonthExpressionDescriptionMetadata.a = null;
    return NextMonthExpressionDescriptionMetadata;
})();
